summaryrefslogtreecommitdiff
path: root/automation/source
diff options
context:
space:
mode:
authorKurt Zenker <kz@openoffice.org>2007-05-11 07:56:01 +0000
committerKurt Zenker <kz@openoffice.org>2007-05-11 07:56:01 +0000
commit0b41434601b28100683f5b8e4083e3e72093220d (patch)
tree2620f4e8f1ba3f18e7d0b8dedeacecea671bc671 /automation/source
parent490a308ab74a8fbd50b6f60e0df5fbe8e290fb08 (diff)
INTEGRATION: CWS gh13 (1.14.26); FILE MERGED
2006/11/22 11:04:57 gh 1.14.26.1: #i22679# new commands to request webpages
Diffstat (limited to 'automation/source')
-rw-r--r--automation/source/testtool/objtest.hxx14
1 files changed, 10 insertions, 4 deletions
diff --git a/automation/source/testtool/objtest.hxx b/automation/source/testtool/objtest.hxx
index 9cce85534018..fa8ad3fee456 100644
--- a/automation/source/testtool/objtest.hxx
+++ b/automation/source/testtool/objtest.hxx
@@ -4,9 +4,9 @@
*
* $RCSfile: objtest.hxx,v $
*
- * $Revision: 1.14 $
+ * $Revision: 1.15 $
*
- * last change: $Author: hr $ $Date: 2006-06-20 00:27:23 $
+ * last change: $Author: kz $ $Date: 2007-05-11 08:56:01 $
*
* The Contents of this file are made available subject to
* the terms of GNU Lesser General Public License Version 2.1.
@@ -50,7 +50,9 @@
#ifndef _SMARTID_HXX_
#include <vcl/smartid.hxx>
#endif
-
+#ifndef _HTTPREQUEST_HXX_
+#include "httprequest.hxx"
+#endif
#include <map>
@@ -110,6 +112,8 @@
#define ID_GetLinkDestination 54
#define ID_GetRegistryValue 55
#define ID_KillApp 56
+#define ID_HTTPSend 57
+#define ID_HTTPSetProxy 58
#define ID_DoNothing 99
void ReadFlatArray( const ControlDefLoad arWas [], CNames *&pNames );
@@ -313,7 +317,9 @@ public:
BOOL bStopOnSyntaxError; // catch syntax errors in testcases or not
- Environment *pChildEnv; // Environment Variables for child Process
+ Environment *pChildEnv; // Environment Variables for child Process
+
+ HttpRequest *pHttpRequest; // used for sending HTTP requests
};